==> owncloud-8.1.0p2.tgz: owncloud/apps/activity/l10n/pt_PT.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Atividade",
    "Personal activity feed for %s" : "Atividade pessoal de feed para %s",
    "Your feed URL is invalid" : "O seu URL de feed é inválido",
    "Your settings have been updated." : "As suas definições foram atualizadas.",
    "This stream will show events like additions, changes & shares" : "Este stream irá mostrar eventos como adições, alterações e partilhas",
    "There are no events for this filter" : "Não existem eventos para este filtro",
    "Activity notification" : "Notificação da Atividade",
    "All Activities" : "Todas as Atividades",
    "Activities by you" : "As suas atividades",
    "Activities by others" : "Atividades de outros",
    "\"remote user\"" : "\"utilizador remoto\"",
    "in %s" : "em %s",
    "%s and %s" : "%s e %s",
    ", " : ", ",
    "_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_" : ["%s e <strong class=\"tooltip\" title=\"%s\">%n mais</strong>","%s e <strong class=\"tooltip\" title=\"%s\">%n mais</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s e %n mais","%s e %n mais"],
    "Hello %s," : "Olá %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "Está a receber esta mensagem porque na última hora ocorreram as seguintes ações às %s",
    "You are receiving this email because in the last day the following things happened at %s" : "Está a receber este e-mail porque no último dia ocorreram as seguintes ações às %s",
    "You are receiving this email because in the last week the following things happened at %s" : "Está a receber este e-mail porque na última semana ocorreram as seguintes ações às %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* e %n mais","* e mais %n"],
    "Notifications" : "Notificações",
    "Mail" : "Correio",
    "Stream" : "Transmissão",
    "List your own actions in the stream" : "Liste as suas próprias ações na transmissão",
    "Notify about your own actions via email" : "Notificações sobre as suas ações via e-mail",
    "You need to set up your email address before you can receive notification emails." : "Precisa de configurar o seu endereço de e-mail antes de poder receber a notificação por e-email.",
    "Send emails:" : "Enviar e-mails:",
    "Hourly" : "Hora a hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Activity feed" : "Atividade de feed",
    "Enable RSS feed" : "Ativar feed RSS",
    "No activity yet" : "Nenhuma actividade para já",
    "No more events to load" : "Sem mais eventos para carregar",
    "Files" : "Ficheiros"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.3.tgz: owncloud/apps/activity/l10n/pt_PT.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Atividade",
    "Personal activity feed for %s" : "Atividade pessoal de feed para %s",
    "Your feed URL is invalid" : "O seu URL de emissão é inválido",
    "Your settings have been updated." : "As suas definições foram atualizadas.",
    "Mail" : "Correio",
    "Stream" : "Transmissão",
    "Activities" : "Atividades",
    "Error loading activities" : "Erro ao carregar as actividades",
    "No activities" : "Sem atividades",
    ", " : ", ",
    "{parameterList} and {lastParameter}" : "{parameterList} e {lastParameter}",
    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} e {linkStart}%n mais{linkEnd}","{parameterList} e {linkStart}%n mais{linkEnd}"],
    "in {directory}" : "em {directory}",
    "This stream will show events like additions, changes & shares" : "Esta transmissão irá mostrar os eventos como adições, alterações e partilhas",
    "There are no events for this filter" : "Não existem eventos para este filtro",
    "Today" : "Hoje",
    "Yesterday" : "Ontem",
    "\"remote user\"" : "\"utilizador remoto\"",
    "Activity notification" : "Notificação da Atividade",
    "All Activities" : "Todas as Atividades",
    "Activities by you" : "As suas atividades",
    "Activities by others" : "Atividades de outros",
    "%s and %s" : "%s e %s",
    "Hello %s," : "Olá %s,",
    "You are receiving this email because the following things happened at %s" : "Está a receber esta mensagem porque porque ocorreu o seguinte às %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* e %n mais","* e mais %n"],
    "List your own actions in the stream" : "Liste as suas próprias ações na transmissão",
    "Notify about your own actions via email" : "Notificações sobre as suas ações via e-mail",
    "You need to set up your email address before you can receive notification emails." : "Precisa de configurar o seu endereço de e-mail antes de poder receber a notificação por e-email.",
    "Send emails:" : "Enviar e-mails:",
    "Hourly" : "Hora a hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Activity feed" : "Atividade de feed",
    "Enable RSS feed" : "Ativar feed RSS",
    "No activity yet" : "Ainda sem atividade",
    "No more events to load" : "Sem mais eventos para carregar",
    "Files" : "Ficheiros"
},
"nplurals=2; plural=(n != 1);");
